workshop_schedules
=========

[![image](https://img.shields.io/pypi/v/workshop_schedules.svg)](https://pypi.python.org/pypi/workshop_schedules)

[![image](https://github.com/WWU-AMM/workshop_schedules/workflows/pytest/badge.svg)](https://github.com/WWU-AMM/workshop_schedules/actions)

[![Documentation Status](https://readthedocs.org/projects/workshop_schedules/badge/?version=latest)](https://workshop_schedules.readthedocs.io/en/latest/?badge=latest)


One-liner to describe the package

-   Free software: BSD license
-   Documentation: <https://workshop_schedules.readthedocs.io>.
-   [![Live examples](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/WWU-AMM/workshop_schedules/HEAD?filepath=docs%2Fexamples%2F)


Features
--------

-   TODO

Credits
-------

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[WWU-AMM/python_cookiecutter](https://github.com/WWU-AMM/python_cookiecutter)
project template.
